@@ -1,7 +1,7 @@
 
 /*
  * speaking.c - Speech Dispatcher speech output functions
- * 
+ *
  * Copyright (C) 2001,2002,2003, 2006, 2007 Brailcom, o.p.s
  *
  * This is free software; you can redistribute it and/or modify it
@@ -29,6 +29,7 @@
 #include <glib.h>
 #include <poll.h>
 #include <unistd.h>
+#include <safe_io.h>
 #include "speechd.h"
 #include "server.h"
 #include "index_marking.h"
@@ -88,9 +89,7 @@ void *speak(void *data)
 				MSG(5,
 				    "wait_for_poll: activity in Speech Dispatcher");
 				const ssize_t rd_bytes =
-				    TEMP_FAILURE_RETRY(read
-						       (poll_fds[0].fd, buf,
-							1));
+				    safe_read(poll_fds[0].fd, buf, 1);
 				if (rd_bytes != 1)
 					FATAL
 					    ("read from polled fd: could not read 1 byte");
@@ -98,10 +97,15 @@ void *speak(void *data)
 		}
 		if (poll_count > 1) {
 			if ((revents = poll_fds[1].revents)) {
-				if ((revents & POLLIN) || (revents & POLLPRI)) {
+				if (revents & POLLHUP) {
+					// FIXME: We should handle this more gracefully
+					FATAL
+					    ("wait_for_poll: output_module disconnected");
+				} else if ((revents & POLLIN)
+					   || (revents & POLLPRI)) {
 					MSG(5,
 					    "wait_for_poll: activity on output_module");
-					/* Check if sb is speaking or they are all silent. 
+					/* Check if sb is speaking or they are all silent.
 					 * If some synthesizer is speaking, we must wait. */
 					is_sb_speaking();
 				}
@@ -151,6 +155,13 @@ void *speak(void *data)
 						MSG(5, "Reloading message");
 						reload_message((TSpeechDMessage
 								*) gl->data);
+						/* If this resumed message is the same as current_message, then it gets
+						 * another trip through the queue.  However, some code later in this
+						 * function will free current_message, even though it is now requeued!
+						 * Hence use-after-free.
+						 * current_message is pretty useless after the requeue, make it NULL. */
+						if (current_message == gl->data)
+							current_message = NULL;
 					} else
 						break;
 				}
@@ -197,7 +208,7 @@ void *speak(void *data)
 			}
 		}
 
-		/* Isn't the parent client of this message paused? 
+		/* Isn't the parent client of this message paused?
 		 * If it is, insert the message to the MessagePausedList. */
 		if (message_nto_speak(message, NULL)) {
 			MSG(4, "Inserting message to paused list...");
@@ -258,11 +269,11 @@ void *speak(void *data)
 						   no outstanding messages. */
 						MSG(4,
 						    "Removing client settings for uid %d",
-						    current_message->settings.
-						    uid);
+						    current_message->
+						    settings.uid);
 						remove_client_settings_by_uid
-						    (current_message->settings.
-						     uid);
+						    (current_message->
+						     settings.uid);
 					}
 				}
 				mem_free_message(current_message);
@@ -430,7 +441,6 @@ void speaking_stop_all()
 	TSpeechDMessage *msg;
 	GList *gl;
 	GList *queue;
-	int gid = -1;
 
 	output_stop();
 
@@ -444,9 +454,7 @@ void speaking_stop_all()
 	assert(gl->data != NULL);
 	msg = (TSpeechDMessage *) gl->data;
 
-	if (msg->settings.reparted != 0) {
-		gid = msg->settings.reparted;
-	} else {
+	if (msg->settings.reparted == 0) {
 		return;
 	}
 
@@ -547,8 +555,9 @@ int speaking_pause(int fd, int uid)
 		    "Including current message into the message paused list");
 		current_message->settings.paused = 2;
 		current_message->settings.paused_while_speaking = 1;
-		MessagePausedList =
-		    g_list_append(MessagePausedList, current_message);
+		if (g_list_find(MessagePausedList, current_message) == NULL)
+			MessagePausedList =
+			    g_list_append(MessagePausedList, current_message);
 	}
 
 	return 0;
@@ -626,21 +635,21 @@ int report_index_mark(TSpeechDMessage * msg, char *index_mark)
 }
 
 #define REPORT_STATE(state, ssip_code, ssip_msg) \
-  int \
-  report_ ## state (TSpeechDMessage *msg) \
-  { \
-    char *cmd; \
-    int ret; \
-    cmd = g_strdup_printf(ssip_code"-%d\r\n"ssip_code"-%d\r\n"ssip_msg, \
-	     msg->id, msg->settings.uid); \
-    ret = socket_send_msg(msg->settings.fd, cmd); \
-    if (ret){ \
-      MSG(2, "ERROR: Can't report index mark!"); \
-      return -1; \
-    } \
-    g_free(cmd); \
-    return 0; \
-  }
+	int \
+	report_ ## state (TSpeechDMessage *msg) \
+	{ \
+		char *cmd; \
+		int ret; \
+		cmd = g_strdup_printf(ssip_code"-%d\r\n"ssip_code"-%d\r\n"ssip_msg, \
+		                      msg->id, msg->settings.uid); \
+		ret = socket_send_msg(msg->settings.fd, cmd); \
+		if (ret){ \
+			MSG(2, "ERROR: Can't report index mark!"); \
+			return -1; \
+		} \
+		g_free(cmd); \
+		return 0; \
+	}
 
 REPORT_STATE(begin, EVENT_BEGIN_C, EVENT_BEGIN)
     REPORT_STATE(end, EVENT_END_C, EVENT_END)
@@ -650,7 +659,6 @@ REPORT_STATE(begin, EVENT_BEGIN_C, EVENT_BEGIN)
 
 int is_sb_speaking(void)
 {
-	int ret;
 	char *index_mark;
 	TFDSetElement *settings;
 
@@ -665,7 +673,7 @@ int is_sb_speaking(void)
 		}
 		settings = &(current_message->settings);
 
-		ret = output_is_speaking(&index_mark);
+		output_is_speaking(&index_mark);
 		if (index_mark == NULL)
 			return SPEAKING = 0;
 
@@ -717,8 +725,8 @@ int is_sb_speaking(void)
 				    index_mark);
 				if (current_message->settings.index_mark !=
 				    NULL)
-					g_free(current_message->settings.
-					       index_mark);
+					g_free(current_message->
+					       settings.index_mark);
 				current_message->settings.index_mark =
 				    g_strdup(index_mark);
 			}
